==> pulumi-3.161.0a1743680850-py3-none-any.whl: pulumi/provider/experimental/component.py <==
# Copyright 2025, Pulumi Corporation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import builtins
from dataclasses import dataclass
from enum import Enum
from typing import Optional, Union


class PropertyType(Enum):
    STRING = "string"
    INTEGER = "integer"
    NUMBER = "number"
    BOOLEAN = "boolean"
    OBJECT = "object"
    ARRAY = "array"


@dataclass
class EnumValueDefinition:
    name: str
    value: Union[str, float, int, bool]
    description: Optional[str] = None


@dataclass
class PropertyDefinition:
    optional: bool = False
    type: Optional[PropertyType] = None
    ref: Optional[str] = None
    description: Optional[str] = None
    items: Optional["PropertyDefinition"] = None
    additional_properties: Optional["PropertyDefinition"] = None
    plain: bool = False


@dataclass
class TypeDefinition:
    name: str
    type: PropertyType
    properties: dict[str, PropertyDefinition]
    properties_mapping: dict[str, str]
    """Mapping from the schema name to the Python name."""
    module: str
    """The Python module where this type is defined."""
    python_type: builtins.type
    """The Python type from which we derived this type definition."""
    description: Optional[str] = None
    enum: Optional[list[EnumValueDefinition]] = None


@dataclass
class ComponentDefinition:
    name: str
    inputs: dict[str, PropertyDefinition]
    outputs: dict[str, PropertyDefinition]
    inputs_mapping: dict[str, str]
    """Mapping from the schema name to the Python name."""
    outputs_mapping: dict[str, str]
    """Mapping from the schema name to the Python name."""
    module: Optional[str]
    """The Python module where this component is defined."""
    description: Optional[str] = None

==> pulumi-3.164.0a1745487575-py3-none-any.whl: pulumi/provider/experimental/component.py <==
# Copyright 2025, Pulumi Corporation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import builtins
from dataclasses import dataclass
from enum import Enum
from typing import Literal, Optional, Union


class PropertyType(Enum):
    STRING = "string"
    INTEGER = "integer"
    NUMBER = "number"
    BOOLEAN = "boolean"
    OBJECT = "object"
    ARRAY = "array"


@dataclass
class EnumValueDefinition:
    name: str
    value: Union[str, float, int, bool]
    description: Optional[str] = None


@dataclass
class PropertyDefinition:
    optional: bool = False
    type: Optional[PropertyType] = None
    ref: Optional[str] = None
    description: Optional[str] = None
    items: Optional["PropertyDefinition"] = None
    additional_properties: Optional["PropertyDefinition"] = None
    plain: Optional[Literal[True]] = None


@dataclass
class TypeDefinition:
    name: str
    type: PropertyType
    properties: dict[str, PropertyDefinition]
    properties_mapping: dict[str, str]
    """Mapping from the schema name to the Python name."""
    module: str
    """The Python module where this type is defined."""
    python_type: builtins.type
    """The Python type from which we derived this type definition."""
    description: Optional[str] = None
    enum: Optional[list[EnumValueDefinition]] = None


@dataclass
class ComponentDefinition:
    name: str
    inputs: dict[str, PropertyDefinition]
    outputs: dict[str, PropertyDefinition]
    inputs_mapping: dict[str, str]
    """Mapping from the schema name to the Python name."""
    outputs_mapping: dict[str, str]
    """Mapping from the schema name to the Python name."""
    module: Optional[str]
    """The Python module where this component is defined."""
    description: Optional[str] = None
